/**
 * @module utils
 */
import { AnyNode } from 'acorn';
type Mapping = Map<string, string>;
type Collector = (key: string, value: string) => void;
/**
 * @function removeFile
 * @description Removes a file from the filesystem if it exists.
 * @param path The path to the file.
 */
export declare function removeFile(path: string): Promise<void>;
/**
 * @function isString
 * @description Checks if a value is a string.
 * @param value The value to check.
 */
export declare function isString(value: unknown): value is string;
/**
 * @function collect
 * @description Collects styles from the given nodes and adds them to the styles array.
 * @param left The left node.
 * @param right The right node.
 * @param collector The collector function.
 */
export declare function collect(left: AnyNode, right: AnyNode, collector: Collector): void;
/**
 * @function parseStyles
 * @description Parses the styles from the given content.
 * @param content The content to parse the styles from.
 */
export declare function parseStyles(content: string): [named: boolean, styles: Mapping, reexports: Mapping];
/**
 * @function generateTypings
 * @description Generate typings for CSS modules.
 * @param content The CSS content.
 * @param banner Optional banner string.
 * @param eol End of line character.
 */
export declare function generateTypings(content: string, banner?: string, eol?: string): string | null;
export {};
